use crate::random_names::get_name;
use crate::state::{Mailbox, State};
use rouille::{post_input, router, try_or_400, Request, Response};

pub fn http_handler(request: &Request, state: &State) -> Response {
    router!(request,
        (GET) (/) => {
            rouille::Response::text("hello world")
        },

        (GET) (/ffff) => {
            rouille::Response::html("<h1>email stuff</h1>")
        },

        (POST) (/ffff) => {
            let data = try_or_400!(post_input!(request, {
                domain: String
        }));

            let email = format!("{}@{}", get_name().to_lowercase(), data.domain);

            println!("{}", email);

            state.lock().unwrap().insert(email.clone(), Mailbox::new(email.clone()));

            rouille::Response::text(email)
        },

        (GET) (/ffff/{email: String}) => {
            println!("{}", email);

            if let Some(mailbox) = state.lock().unwrap().get(&email) {
                let body: &Vec<String> = &mailbox.messages.iter().map(|msg| {
                   return format!("<h3>From {}<h3><br><pre>{}</pre><br>", msg.sender, msg.data)
                }).collect();

                rouille::Response::html(body.join(""))
            } else {
                rouille::Response::text("Mailbox not found")
            }
        },

        _ => rouille::Response::empty_404()
    )
}
